class PropertyError(KeyError): ...
class IdError(KeyError): ...
class ItemSelectionModeError(ValueError): ...

# DATABASE
class TableNotFoundError(ValueError): ...
class HeaderError(ValueError): ...
class DataTypeError(ValueError): ...
class TableExistsError(ValueError): ...
class InvalidValueError(ValueError): ...